@@ -1,6 +1,6 @@
 /* daisy-player
  *
- * Copyright (C)2003-2017 J. Lemmens
+ * Copyright (C)2003-2018 J. Lemmens
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -91,7 +91,7 @@ void get_clips (misc_t *misc, my_attribute_t *my_attribute)
 float read_time (char *p)
 {
    char *h, *m, *s;
-              
+
    s = strrchr (p, ':') + 1;
    if (s > p)
       *(s - 1) = 0;
@@ -160,10 +160,7 @@ void get_bookmark (misc_t *misc, my_attribute_t *my_attribute,
    while (1)
    {
       if (strcmp (misc->current_id, id) == 0)
-      {
-         start_playing (misc, daisy);
          break;
-      } // if
       get_next_clips (misc, my_attribute, daisy);
    } // while
    if (misc->level < 1)
@@ -173,7 +170,7 @@ void get_bookmark (misc_t *misc, my_attribute_t *my_attribute,
    pause_resume (misc, my_attribute, daisy);
    pause_resume (misc, my_attribute, daisy);
    view_screen (misc, daisy);
-} // get_bookmark        
+} // get_bookmark
 
 void get_next_clips (misc_t *misc, my_attribute_t *my_attribute,
                     daisy_t *daisy)
@@ -185,7 +182,8 @@ void get_next_clips (misc_t *misc, my_attribute_t *my_attribute,
       eof = 1 - get_tag_or_label (misc, my_attribute, misc->reader);
       if (strcasecmp (misc->tag, "audio") == 0)
       {
-         misc->current_audio_file = real_name (misc, my_attribute->src);
+         misc->current_audio_file =
+                         convert_URL_name (misc, my_attribute->src);
          get_clips (misc, my_attribute);
          return;
       } // if
@@ -227,7 +225,7 @@ void get_next_clips (misc_t *misc, my_attribute_t *my_attribute,
                snprintf (name, len, "%s/.daisy-player/%s%s",
                          pw->pw_dir, misc->bookmark_title, get_mcn (misc));
                unlink (name);
-               _exit (0);
+               _exit (-1);
             } // if
             if (daisy[misc->playing].level <= misc->level)
                misc->displaying = misc->current = misc->playing;
@@ -301,7 +299,7 @@ void view_time (misc_t *misc, daisy_t *daisy)
    wattroff (misc->screenwin, A_BOLD);
    wmove (misc->screenwin, daisy[misc->current].y, daisy[misc->current].x);
    wrefresh (misc->screenwin);
-} // view_time                                                       
+} // view_time
 
 void view_screen (misc_t *misc, daisy_t *daisy)
 {
@@ -405,7 +403,8 @@ void start_playing (misc_t *misc, daisy_t *daisy)
    snprintf (duration, 20, "%f", misc->clip_end - misc->clip_begin);
    madplay (misc->current_audio_file, begin, duration, misc->tmp_wav);
    snprintf (tempo_str, 10, "%lf", misc->speed);
-   playfile (misc, misc->tmp_wav, "wav", misc->sound_dev, "alsa", tempo_str);
+   misc->player_pid = setpgrp ();
+   playfile (misc, misc->tmp_wav, "wav", misc->sound_dev, "pulseaudio", tempo_str);
    _exit (0);
 } // start_playing
 
@@ -421,7 +420,7 @@ void open_clips_file (misc_t *misc, my_attribute_t *my_attribute,
 
       e = errno;
       snprintf (str, MAX_STR, "htmlParseFile (%s)", clips_file);
-      failure (misc,  str, e);                                
+      failure (misc,  str, e);
    } // if
    if (! (misc->reader = xmlReaderWalker (misc->doc)))
    {
@@ -433,7 +432,7 @@ void open_clips_file (misc_t *misc, my_attribute_t *my_attribute,
       failure (misc, str, e);
    } // if
 
-   if (*anchor == 0)
+   if (*anchor == 0)                                    
       return;
 
 // skip to anchor
@@ -449,17 +448,20 @@ void open_clips_file (misc_t *misc, my_attribute_t *my_attribute,
 void write_wav (misc_t *misc, my_attribute_t *my_attribute,
                 daisy_t *daisy, char *label)
 {
-   char in_file[MAX_STR], out_file[MAX_STR];
-   char  out_cdr[MAX_STR], complete_cdr[MAX_STR];
+   char *out_file, *out_cdr, *complete_cdr, *cmd;
    struct passwd *pw;
    int old_playing, old_displaying, old_current, old_just_this_item;
    char begin[20], duration[20];
    int w;
 
    pw = getpwuid (geteuid ());
-   snprintf (out_file, MAX_STR, "%s/%s.wav", pw->pw_dir, label);
+   out_file = malloc (strlen (pw->pw_dir) + strlen (label) + 10);
+   sprintf (out_file, "%s/%s.wav", pw->pw_dir, label);
    while (access (out_file, R_OK) == 0)
-      strncat (out_file, ".wav", MAX_STR - 1);
+   {
+      out_file = realloc (out_file, strlen (out_file) + 5);
+      strcat (out_file, ".wav");
+   } // while
 
    if (misc->cd_type == CDIO_DISC_MODE_CD_DA)
    {
@@ -481,6 +483,7 @@ void write_wav (misc_t *misc, my_attribute_t *my_attribute,
       if (misc->par)
          paranoia_free (misc->par);
 // The .wav file is not correctly closed; I don't know the solution, sorry.
+      free (out_file);
       kill (pid, SIGQUIT);
       return;
    } // if
@@ -491,8 +494,10 @@ void write_wav (misc_t *misc, my_attribute_t *my_attribute,
    old_just_this_item = misc->just_this_item;
    misc->just_this_item = misc->playing = misc->current;
 
-   snprintf (out_cdr, MAX_STR, "%s/out.cdr", misc->tmp_dir);
-   snprintf (complete_cdr, MAX_STR, "%s/complete.cdr", misc->tmp_dir);
+   out_cdr = malloc (strlen (misc->tmp_dir) + 10);
+   sprintf (out_cdr, "%s/out.cdr", misc->tmp_dir);
+   complete_cdr = malloc (strlen (misc->tmp_dir) + 20);
+   sprintf (complete_cdr, "%s/complete.cdr", misc->tmp_dir);
    w = open (complete_cdr, O_WRONLY | O_CREAT | O_TRUNC, S_IRWXU);
    while (1)
    {
@@ -506,11 +511,17 @@ void write_wav (misc_t *misc, my_attribute_t *my_attribute,
       get_next_clips (misc, my_attribute, daisy);
       snprintf (begin, 20, "%f", daisy[misc->current].begin);
       snprintf (duration, 20, "%f", daisy[misc->current].duration);
-      snprintf (in_file, MAX_STR, "%s/%s",
-                misc->daisy_mp, misc->current_audio_file);
-      if (access (in_file, R_OK) != 0)
-         failure (misc, in_file, errno);
-      madplay (in_file, begin, duration, out_cdr);
+      if (access (misc->current_audio_file, R_OK) == -1)
+      {
+         int e;
+
+         e= errno;
+         endwin ();
+         beep ();
+         printf ("%s: %s\n", misc->current_audio_file, strerror (e));
+         _exit (-1);
+      } // if
+      madplay (misc->current_audio_file, begin, duration, out_cdr);
       r = open (out_cdr, O_RDONLY);
       while ((in = read (r, &buffer, BUF_SIZE)) > 0)
       {
@@ -520,13 +531,20 @@ void write_wav (misc_t *misc, my_attribute_t *my_attribute,
       } // while
       close (r);
       if (misc->current + 1 >= misc->total_items)
-        break;
+         break;
       if (daisy[misc->current + 1].level <= misc->level)
          break;
       misc->current += 1;
    } // while
    close (w);
-   playfile (misc, complete_cdr, "cdr", out_file, "wav", "1");
+//   playfile (misc, complete_cdr, "cdr", out_file, "wav", "1");
+   cmd = malloc (strlen (complete_cdr) + strlen (out_file) + 50);
+   sprintf (cmd, "sox -t cdr \"%s\" -t wav \"%s\"", complete_cdr,  out_file);
+   switch (system (cmd));
+   free (out_file);
+   free (out_cdr);
+   free (complete_cdr);
+   free (cmd);
    misc->playing = old_playing;
    misc->displaying = old_displaying;
    misc->current= old_current;
@@ -542,13 +560,7 @@ void pause_resume (misc_t *misc, my_attribute_t *my_attribute, daisy_t *daisy)
       misc->pause_resume_id = misc->current_id;
       misc->playing = -1;
       misc->pause_resume_lsn_cursor = misc->lsn_cursor;
-      while (kill (misc->player_pid, SIGKILL) == 0);
-      if (misc->cd_type != CDIO_DISC_MODE_CD_DA)
-      {
-         misc->player_pid = -2;
-      }
-      else
-         while (kill (misc->cdda_pid, SIGKILL) == 0);
+      kill_player (misc);
       return;
    } // if
 
@@ -556,7 +568,7 @@ void pause_resume (misc_t *misc, my_attribute_t *my_attribute, daisy_t *daisy)
    misc->lsn_cursor = misc->pause_resume_lsn_cursor;
    if (misc->cd_type == CDIO_DISC_MODE_CD_DA)
    {
-      misc->player_pid = play_track (misc, misc->sound_dev, "alsa",
+      misc->player_pid = play_track (misc, misc->sound_dev, "pulseaudio",
                                      misc->pause_resume_lsn_cursor - 75 * 4);
       return;
    } // if
@@ -769,7 +781,7 @@ void calculate_times_3 (misc_t *misc, my_attribute_t *my_attribute,
             break;
 // get misc->clip_begin
          if (strcasecmp (misc->tag, "audio") == 0)
-         {                                 
+         {
             misc->has_audio_tag = 1;
             get_clips (misc, my_attribute);
             daisy[x].begin = misc->clip_begin;
@@ -797,7 +809,7 @@ void calculate_times_3 (misc_t *misc, my_attribute_t *my_attribute,
                   daisy[x].duration += misc->clip_end - misc->clip_begin;
                } // IF
             } // while
-            if (x < misc->total_items - 1 && *daisy[x + 1].clips_anchor)
+            if (x < misc->total_items - 1 && *daisy[x + 1].clips_anchor)     
                if (strcasecmp
                            (my_attribute->id, daisy[x + 1].clips_anchor) == 0)
                   break;
@@ -813,7 +825,7 @@ void calculate_times_3 (misc_t *misc, my_attribute_t *my_attribute,
       quit_daisy_player (misc, daisy);
       printf ("%s\n", gettext (
         "This book has no audio. Play this book with eBook-speaker"));
-      _exit (0);
+      _exit (-1);
    } // if
 } // calculate_times_3
 
@@ -861,7 +873,7 @@ void load_xml (misc_t *misc, my_attribute_t *my_attribute)
    doc = xmlRecoverFile (str);
    if (! (reader = xmlReaderWalker (doc)))
    {
-      strncpy (misc->sound_dev, "hw:0", MAX_STR - 1);
+      strncpy (misc->sound_dev, "0", MAX_STR - 1);
       return;
    } // if
    do
@@ -906,16 +918,9 @@ void quit_daisy_player (misc_t *misc, daisy_t *daisy)
 {
    view_screen (misc, daisy);
    endwin ();
-   if (misc->cd_type == CDIO_DISC_MODE_CD_DA)
-   {
-      while (kill (misc->player_pid, SIGKILL) == 0);
-      while (kill (misc->cdda_pid, SIGKILL) == 0);
-   }
-   else
-   {
+   if (misc->cd_type != CDIO_DISC_MODE_CD_DA)
       xmlTextReaderClose (misc->reader);
-      while (kill (misc->player_pid, SIGKILL) == 0);
-   } // if
+   kill_player (misc);
    put_bookmark (misc);
    save_xml (misc);
    close (misc->tmp_wav_fd);
@@ -1002,7 +1007,7 @@ void search (misc_t *misc, my_attribute_t *my_attribute, daisy_t *daisy,
       if (misc->cd_type == CDIO_DISC_MODE_CD_DA)
       {
          misc->elapsed_seconds = time (NULL);
-         misc->player_pid = play_track (misc, misc->sound_dev, "alsa",
+         misc->player_pid = play_track (misc, misc->sound_dev, "pulseaudio",
                 daisy[misc->current].first_lsn);
       }
       else
@@ -1032,12 +1037,10 @@ void go_to_time (misc_t *misc, daisy_t *daisy, my_attribute_t *my_attribute)
 {
    char time_str[10];
    int secs;
-
-   while (kill (misc->player_pid, SIGKILL) == 0);
+                                
+   kill_player (misc);
    if (misc->cd_type != CDIO_DISC_MODE_CD_DA)
       misc->player_pid = -2;
-   else
-      while (kill (misc->cdda_pid, SIGKILL) == 0);
    misc->just_this_item = -1;
    misc->playing = misc->displaying = misc->current;
    view_screen (misc, daisy);
@@ -1075,7 +1078,7 @@ void go_to_time (misc_t *misc, daisy_t *daisy, my_attribute_t *my_attribute)
    } // if
    if (misc->cd_type == CDIO_DISC_MODE_CD_DA)
    {
-      misc->player_pid = play_track (misc, misc->sound_dev, "alsa",
+      misc->player_pid = play_track (misc, misc->sound_dev, "pulseaudio",
                          daisy[misc->current].first_lsn + (secs * 75));
       misc->elapsed_seconds = time (NULL) - secs;
       misc->prev_id = strdup (misc->current_id);
@@ -1118,7 +1121,7 @@ void skip_left (misc_t *misc, my_attribute_t *my_attribute,
    } // if first item
    if (misc->player_pid > -1)
    {
-      while (kill (misc->player_pid, SIGKILL) != 0);
+      kill_player (misc);
       misc->player_pid = -2;
    } // if
    if (misc->reader)
@@ -1175,6 +1178,11 @@ void browse (misc_t *misc, my_attribute_t *my_attribute,
    misc->pause_resume_playing = misc->just_this_item = -1;
    misc->label_len = 0;
    get_bookmark (misc, my_attribute, daisy);
+
+// convert ALSA device name into pulseaudio device name
+   if (strncmp (misc->sound_dev, "hw:", 3) == 0)
+      misc->sound_dev += 3;
+
    if (misc->cd_type == CDIO_DISC_MODE_CD_DA)
    {
       for (i = 0; i < misc->total_items; i++)
@@ -1183,7 +1191,7 @@ void browse (misc_t *misc, my_attribute_t *my_attribute,
          daisy[i].page_number = 0;
       } // for
       misc->depth = 1;
-      misc->player_pid = play_track (misc, misc->sound_dev, "alsa",
+      misc->player_pid = play_track (misc, misc->sound_dev, "pulseaudio",
                       daisy[misc->current].first_lsn + (misc->seconds * 75));
       misc->elapsed_seconds = time (NULL) - misc->seconds;
    } // if
@@ -1196,7 +1204,7 @@ void browse (misc_t *misc, my_attribute_t *my_attribute,
       quit_daisy_player (misc, daisy);
       printf ("%s\n", gettext (
         "This book has no audio. Play this book with eBook-speaker"));
-      _exit (0);
+      _exit (-1);
    } // if
 
    for (;;)
@@ -1210,7 +1218,7 @@ void browse (misc_t *misc, my_attribute_t *my_attribute,
          misc->current_id = strdup ("");
          misc->current_page_number = daisy[misc->playing].page_number;
          if (misc->player_pid > -1)
-            kill (misc->player_pid, SIGKILL);
+            kill_player (misc);
          misc->player_pid = -2;
          if (misc->discinfo)
          {
@@ -1236,7 +1244,7 @@ void browse (misc_t *misc, my_attribute_t *my_attribute,
          } // if
          if (misc->cd_type == CDIO_DISC_MODE_CD_DA)
          {
-            misc->player_pid = play_track (misc, misc->sound_dev, "alsa",
+            misc->player_pid = play_track (misc, misc->sound_dev, "pulseaudio",
                 daisy[misc->current].first_lsn);
             misc->elapsed_seconds = time (NULL);
             break;
@@ -1330,17 +1338,19 @@ void browse (misc_t *misc, my_attribute_t *my_attribute,
          {
             misc->just_this_item = misc->displaying = misc->playing =
                                    misc->current;
-            kill (misc->player_pid, SIGKILL);
+            kill_player (misc);
             misc->player_pid = -2;
             if (misc->cd_type == CDIO_DISC_MODE_CD_DA)
             {
-               misc->player_pid = play_track (misc, misc->sound_dev, "alsa",
+               misc->player_pid = play_track (misc, misc->sound_dev, "pulseaudio",
                    daisy[misc->current].first_lsn);
             }
             else
+            {
                open_clips_file (misc, my_attribute,
                  daisy[misc->current].clips_file,
                  daisy[misc->current].clips_anchor);
+            } // if
          } // if
          wattron (misc->screenwin, A_BOLD);
          if (misc->just_this_item != -1 &&
@@ -1395,11 +1405,9 @@ void browse (misc_t *misc, my_attribute_t *my_attribute,
          quit_daisy_player (misc, daisy);
          _exit (0);
       case 's':
-         while (kill (misc->player_pid, SIGKILL) == 0);
+         kill_player (misc);
          if (misc->cd_type != CDIO_DISC_MODE_CD_DA)
             misc->player_pid = -2;
-         else
-            while (kill (misc->cdda_pid, SIGKILL) == 0);
          misc->playing = misc->just_this_item = -1;
          view_screen (misc, daisy);
          wmove (misc->screenwin, daisy[misc->current].y,
@@ -1424,7 +1432,7 @@ void browse (misc_t *misc, my_attribute_t *my_attribute,
       case '6':
          if (misc->cd_type == CDIO_DISC_MODE_CD_DA)
          {
-            while (kill (misc->player_pid, SIGKILL) == 0);
+            kill_player (misc);
             misc->lsn_cursor += 8 * 75;
             if (misc->lsn_cursor >= daisy[misc->playing].last_lsn)
             {
@@ -1455,7 +1463,7 @@ void browse (misc_t *misc, my_attribute_t *my_attribute,
                   _exit (0);
                } // if
             } // if
-            misc->player_pid = play_track (misc, misc->sound_dev, "alsa",
+            misc->player_pid = play_track (misc, misc->sound_dev, "pulseaudio",
                                misc->lsn_cursor);
             break;
          } // if
@@ -1465,7 +1473,7 @@ void browse (misc_t *misc, my_attribute_t *my_attribute,
       case '4':
          if (misc->cd_type == CDIO_DISC_MODE_CD_DA)
          {
-            while (kill (misc->player_pid, SIGKILL) == 0);
+            kill_player (misc);
             misc->lsn_cursor -= 12 * 75;
             if (misc->lsn_cursor < daisy[misc->playing].first_lsn)
             {
@@ -1478,7 +1486,7 @@ void browse (misc_t *misc, my_attribute_t *my_attribute,
                   if (misc->lsn_cursor < daisy[misc->playing].first_lsn)
                      misc->lsn_cursor = daisy[misc->playing].first_lsn;
             } // if
-            misc->player_pid = play_track (misc, misc->sound_dev, "alsa",
+            misc->player_pid = play_track (misc, misc->sound_dev, "pulseaudio",
                         misc->lsn_cursor);
             break;
          } // if
@@ -1545,6 +1553,7 @@ void browse (misc_t *misc, my_attribute_t *my_attribute,
          break;
       case 'v':
       case '1':
+         get_volume (misc);
          if (misc->volume <= misc->min_vol)
          {
             beep ();
@@ -1555,6 +1564,7 @@ void browse (misc_t *misc, my_attribute_t *my_attribute,
          break;
       case 'V':
       case '7':
+         get_volume (misc);
          if (misc->volume >= misc->max_vol)
          {
             beep ();
@@ -1627,7 +1637,7 @@ void browse (misc_t *misc, my_attribute_t *my_attribute,
             } // if
             if (misc->just_this_item > -1)
             {
-               kill (misc->player_pid, SIGKILL);
+               kill_player (misc);
                misc->playing = misc->just_this_item = -1;
             } // if
             view_screen (misc, daisy);
@@ -1641,11 +1651,11 @@ void browse (misc_t *misc, my_attribute_t *my_attribute,
 void usage (int e)
 {
    printf (gettext ("Daisy-player - Version %s %s"), PACKAGE_VERSION, "\n");
-   puts ("(C)2003-2017 J. Lemmens\n");
+   puts ("(C)2003-2018 J. Lemmens\n");
    printf (gettext
     ("Usage: %s [directory_with_a_Daisy-structure] | [Daisy_book_archive]"),
     PACKAGE);
-   printf ("\n%s ", gettext ("[-c cdrom_device] [-d ALSA_sound_device]"));
+   printf ("\n%s ", gettext ("[-c cdrom_device] [-d pulseaudio_sound_device]"));
    printf ("[-h] [-i] [-n | -y]\n");
    fflush (stdout);
    _exit (e);
@@ -1741,7 +1751,7 @@ void handle_discinfo (misc_t *misc, my_attribute_t *my_attribute,
                break;
          } while (! *misc->label);
          *daisy[misc->current].label = 0;
-         strncpy (daisy[misc->current].daisy_mp, 
+         strncpy (daisy[misc->current].daisy_mp,
                   dirname (daisy[misc->current].filename), MAX_STR - 1);
          daisy[misc->current].level = 1;
          daisy[misc->current].x = 0;
@@ -1767,6 +1777,7 @@ void handle_discinfo (misc_t *misc, my_attribute_t *my_attribute,
 
 int main (int argc, char *argv[])
 {
+
    int opt;
    char str[MAX_STR], DISCINFO_HTML[MAX_STR], *start_wd;
    char *c_opt, *d_opt, cddb_opt;
@@ -1774,10 +1785,6 @@ int main (int argc, char *argv[])
    my_attribute_t my_attribute;
    daisy_t *daisy;
    struct sigaction usr_action;
-   snd_mixer_t *handle;
-   snd_mixer_selem_id_t *sid;
-   snd_mixer_elem_t *elem;
-   snd_mixer_selem_channel_id_t cid;
 
    daisy = NULL;
    misc.tmp_dir = misc.label = NULL;
@@ -1799,7 +1806,9 @@ int main (int argc, char *argv[])
    *misc.xmlversion = 0;
 // If option '-h' exit before load_xml ()
    make_tmp_dir (&misc);
-   strncpy (misc.sound_dev, "hw:0", MAX_STR - 1);
+   if (access ("/usr/bin/sox", R_OK) != 0)
+      failure (&misc, "daisy-player needs the sox package.", errno);
+   misc.sound_dev = strdup ("0");
    misc.cddb_flag = 'y';
    if (! setlocale (LC_ALL, ""))
       failure (&misc, "setlocale ()", errno);
@@ -1822,10 +1831,11 @@ int main (int argc, char *argv[])
          c_opt = strdup (misc.cd_dev);
          break;
       case 'd':
-         strncpy (misc.sound_dev, optarg, 15);
+         misc.sound_dev = strdup (optarg);
          d_opt = strdup (misc.sound_dev);
          break;
       case 'h':
+         free (start_wd);
          remove_tmp_dir (&misc);
          usage (0);
          break;
@@ -1857,7 +1867,7 @@ int main (int argc, char *argv[])
          misc.use_OPF = 1;
          break;
       default:
-         beep ();
+         beep ();             
          remove_tmp_dir (&misc);
          usage (1);
       } // switch
@@ -1867,31 +1877,16 @@ int main (int argc, char *argv[])
    if (c_opt)
       strncpy (misc.cd_dev, c_opt, MAX_STR - 1);
    if (d_opt)
-      strncpy (misc.sound_dev, d_opt, MAX_STR - 1);
+      misc.sound_dev = strdup (d_opt);
    if (cddb_opt)
       misc.cddb_flag = cddb_opt;
-   if (snd_mixer_open (&handle, 0) != 0)
-      failure (&misc, "No ALSA sound device found", errno);
-   snd_mixer_attach (handle, misc.sound_dev);
-   snd_mixer_selem_register (handle, NULL, NULL);
-   snd_mixer_load (handle);
-   snd_mixer_selem_id_alloca (&sid);
-   snd_mixer_selem_id_set_index (sid, 0);
-   snd_mixer_selem_id_set_name (sid, "Master");
-   if ((elem = snd_mixer_find_selem (handle, sid)) == NULL)
-      failure (&misc, "No ALSA sound device found", errno);
-   snd_mixer_selem_get_playback_volume_range (elem,
-                                              &misc.min_vol, &misc.max_vol);
-   cid = 0;
-   snd_mixer_selem_get_playback_volume (elem, cid, &misc.volume);
-   snd_mixer_close (handle);
    initscr ();
    if (! (misc.titlewin = newwin (2, 80,  0, 0)) ||
        ! (misc.screenwin = newwin (23, 80, 2, 0)))
       failure (&misc, "No curses", errno);
    fclose (stderr);
    getmaxyx (misc.screenwin, misc.max_y, misc.max_x);
-   printw ("(C)2003-2017 J. Lemmens\n");
+   printw ("(C)2003-2018 J. Lemmens\n");
    printw (gettext ("Daisy-player - Version %s %s"), PACKAGE_VERSION, "");
    printw ("\n");
    printw (gettext ("A parser to play Daisy CD's with Linux"));
@@ -1912,7 +1907,7 @@ int main (int argc, char *argv[])
          endwin ();
          printf (gettext ("Daisy-player - Version %s %s"),
                  PACKAGE_VERSION, "\n");
-         puts ("(C)2003-2017 J. Lemmens");
+         puts ("(C)2003-2018 J. Lemmens");
          beep ();
          remove_tmp_dir (&misc);
          printf ("%s: %s\n", argv[optind], strerror (e));
@@ -1977,7 +1972,7 @@ int main (int argc, char *argv[])
 
          if (! (dir = opendir (misc.tmp_dir)))
             failure (&misc, misc.tmp_dir, errno);
-         while ((dirent = readdir (dir)) != NULL)
+         while ((dirent = readdir (dir)) != NULL)         
          {
             if (strcasecmp (dirent->d_name, ".") == 0 ||
                 strcasecmp (dirent->d_name, "..") == 0)
@@ -2016,7 +2011,7 @@ int main (int argc, char *argv[])
          endwin ();
          printf (gettext ("Daisy-player - Version %s %s"),
                           PACKAGE_VERSION, "\n");
-         puts ("(C)2003-2017 J. Lemmens");
+         puts ("(C)2003-2018 J. Lemmens");
          beep ();
          remove_tmp_dir (&misc);
          snprintf (misc.str, MAX_STR, gettext ("Cannot read %s"),
@@ -2032,7 +2027,7 @@ int main (int argc, char *argv[])
          endwin ();
          printf (gettext ("Daisy-player - Version %s %s"),
                           PACKAGE_VERSION, "\n");
-         puts ("(C)2003-2017 J. Lemmens");
+         puts ("(C)2003-2018 J. Lemmens");
          beep ();
          remove_tmp_dir (&misc);
          printf ("\n%s is not a cd device\n", misc.cd_dev);
@@ -2131,7 +2126,7 @@ int main (int argc, char *argv[])
       } while (misc.cd_type == -1);
    } // if use misc.cd_dev
    keypad (misc.screenwin, TRUE);
-   meta (misc.screenwin,       TRUE);
+   meta (misc.screenwin, TRUE);
    nonl ();
    noecho ();
    misc.player_pid = -2;
@@ -2238,7 +2233,7 @@ int main (int argc, char *argv[])
 
    wattron (misc.titlewin, A_BOLD);
    snprintf (str, MAX_STR - 1, gettext (
-        "Daisy-player - Version %s - (C)2017 J. Lemmens"), PACKAGE_VERSION);
+        "Daisy-player - Version %s - (C)2018 J. Lemmens"), PACKAGE_VERSION);
    mvwprintw (misc.titlewin, 0, 0, str);
    wrefresh (misc.titlewin);
 
@@ -2253,7 +2248,7 @@ int main (int argc, char *argv[])
    wprintw (misc.titlewin, "----------------------------------------");
    mvwprintw (misc.titlewin, 1, 0, "%s ", gettext ("Press 'h' for help"));
    misc.level = 1;
-   *misc.search_str = 0;
+   misc.search_str = misc.path_name = strdup ("");
    snprintf (misc.tmp_wav, MAX_STR, "%s/daisy-player.wav", misc.tmp_dir);
    if ((misc.tmp_wav_fd = mkstemp (misc.tmp_wav)) == 01)
       failure (&misc, "mkstemp ()", errno);
