@@ -1,6 +1,6 @@
 /* paranoia.c
  *
- *  Copyright (C)2015 J. Lemmens
+ *  Copyright (C)2017 J. Lemmens
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -63,27 +63,27 @@ void init_paranoia (misc_t *misc)
 pid_t play_track (misc_t *misc, char *out_file, char *type,
                   lsn_t from)
 {
-   cdio_paranoia_free (misc->par);
    init_paranoia (misc);
-   switch (misc->player_pid = fork ())
+   switch (misc->cdda_pid = fork ())
    {
    case 0: /* Child reads from pipe */
    {
-      char path[MAX_STR + 1], str[MAX_STR + 1];
+      char path[MAX_STR + 1];
 
       close (misc->pipefd[1]);     /* don't need this in child */
 #ifdef F_SETPIPE_SZ
       fcntl (misc->pipefd[0], F_SETPIPE_SZ, 1024000);
 #endif
       snprintf (path, MAX_STR, "/dev/fd/%d", misc->pipefd[0]);
-      snprintf (str, MAX_STR, "%f", misc->speed);
-      playfile (misc, path, "cdda", out_file, type, str);
+      snprintf (misc->str, MAX_STR, "%f", misc->speed);
+      misc->cdda_pid = setpgrp ();
+      playfile (misc, path, "cdda", out_file, type, misc->str);
       close (misc->pipefd[0]);
       _exit (0);
    }
    default:
       paranoia_seek (misc->par, from, SEEK_SET);
       misc->lsn_cursor = from;
-      return misc->player_pid;
+      return misc->cdda_pid;
    } // switch
-} // play_track                      
+} // play_track
